// importing the d3 library's required functions
import { csv, select } from 'd3';
// the scatterPlot function is being imported from a local module
import { scatterPlot } from './scatterPlot';

// Sample dataset
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'arun-thotakuri/', // User
  '4cfeeb36976ec98561685576680c3465/', // Id of the Gist
  'raw/ef9e6f6ada4185e3b39c1d70e433bc35e591fe28/', // commit
  'diabates.csv', // File name
].join('');

// A function to parse each CSV row and translate specific attributes to numbers
const parseRow = (d) => {
  d.Pregnancies = +d.Pregnancies;
  d.Glucose = +d.Glucose;
  d.BloodPressure = +d.BloodPressure;
  d.SkinThickness = +d.SkinThickness;
  return d;
};

// Adjusting the SVG canvas's width and height to fit the dimensions of the window
const width = window.innerWidth;
const height = window.innerHeight - 10;

// Making an SVG element with a defined width and height that is affixed to the page's body
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Main asynchronous function for data loading and plotting creation
const main = async () => {
  // Instantiating a scatter plot with specified settings

  // **Customization Point 1: Modify plot appearance (colors, markers, labels):**
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow)) // parsing and loading information from the CSV URL
    .xValue((d) => d.Pregnancies) // Value accessor for X-axis (replace with desired column)
    .yValue((d) => d.Glucose) // Value accessor on the Y-axis
    .margin({
      // Determining the plot's margins
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(8); // The scatter plot points' radius


  svg.call(plot);

  // The x-axis value is an array of column names that must be cycled through.
  const columns = [
    'BMI',
    'Glucose',
    'BloodPressure',
    'SkinThickness',
  ];

  // setting up a counter so that it can cycle over the columns
  let i = 0;

  // establishing a time interval to redraw the plot and update the x-axis value
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]); // Altering the value accessor for the x-axis
    svg.call(plot); // Plotting again using the updated x-axis values
    i++; // Increasing the counter correspondingly
  }, 2000); // **Customization Point 3: Change animation interval (time in milliseconds):**
};

// carrying out the main task to develop the plot
main();
